@@ -1,11 +1,8 @@
 """NotebookNode - adding attribute access to dicts"""
 
-from ._struct import Struct
+from collections.abc import Mapping
 
-try:
-    from collections.abc import Mapping
-except ImportError:
-    from collections import Mapping
+from ._struct import Struct
 
 
 class NotebookNode(Struct):
